# Unmasking the Dark Side of Low-Code/No-Code Applications
## LCNC apps and RPA can leave your business exposed to security risks similar to traditional development.
## Information:

+ Link: https://thehackernews.com/2023/12/unmasking-dark-side-of-low-codeno-code.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 18 December 2023, 16:01
+ Date scraped: 18 December 2023, 11:49

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjN0OM5bZjWV7_W648impTIBUcGU5yOpe6lNGQssdf44C_oQwra9ajloW3UkQJcJEjGwuD-oq7F6tibfJELhZwMyZ6l8TywymrtF4xVUfWdYVWdh4JwV_BfStrqryN18lJPOud-vXFpHpihnyu3wSMHuTpVFA3jqU9JOiz7f9Tc5w-gHU6akUTm23zedow/s728-rw-ft-e30/nokod.jpg)


Low-code/no-code (LCNC) and robotic process automation (RPA) have gained immense popularity, but how secure are they? Is your security team paying enough attention in an era of rapid digital transformation, where business users are empowered to create applications swiftly using platforms like Microsoft PowerApps, UiPath, ServiceNow, Mendix, and OutSystems?


The simple truth is often swept under the rug. While low-code/no-code (LCNC) apps and robotic process automations (RPA) drive efficiency and agility, their dark security side demands scrutiny. LCNC application security emerges as a relatively new frontier, and even seasoned security practitioners and security teams grapple with the dynamic nature and sheer volume of citizen-developed applications. The accelerated pace of LCNC development poses a unique challenge for security professionals, underscoring the need for dedicated efforts and solutions to effectively address the security nuances of low-code development environments.


**Digital Transformation: Trading off Security?**[#](#digital-transformation-trading-off-security)
--------------------------------------------------------------------------------------------------


One reason security finds itself in the backseat is a common concern that security controls are potential speed bumps in the digital transformation journey. Many citizen developers strive for quick app creation but unknowingly create new risks simultaneously.


The fact is that LCNC apps leave many business applications exposed to the same risks and damage as their traditionally developed counterparts. Ultimately, it takes a closely aligned [security solution for LCNC](https://nokodsecurity.com?utm_source=media&utm_medium=article&utm_campaign=THN2023) to balance business success, continuity, and security. 


As organizations dive headfirst into LCNC and RPA solutions, it's time to acknowledge that the current AppSec stack is inadequate for safeguarding critical assets and data exposed by LCNC apps. Most organizations are left with manual, cumbersome security for LCNC development.


**Unlocking Uniqueness: Security Challenges in LCNC and RPA Environments**[#](#unlocking-uniqueness-security-challenges-in-lcnc-and-rpa-environments)
-----------------------------------------------------------------------------------------------------------------------------------------------------


While the security challenges and threat vectors in LCNC and RPA environments might appear similar to traditional software development, the devil is in the details. Democratizing software development across a wider audience, the development environments, processes, and participants in LCNC and RPA introduce a transformative shift. This kind of decentralized app creation comes with three main challenges.


First, citizen and automation developers tend to be more prone to unintentional, logical errors that may result in security vulnerabilities. Second, from a visibility point of view, security teams are dealing with a new kind of shadow IT, or to be more precise, Shadow Engineering. Third, security teams have little to no control over the LCNC app life cycle.


**Governance, Compliance, Security: A Triple Threat**[#](#governance-compliance-security-a-triple-threat)
---------------------------------------------------------------------------------------------------------


The three-headed monster haunting CISOs, security architects, and security teams – governance, compliance, and security – is ever more ominous in LCNC and RPA environments. To illustrate, here are some and, of course, not comprehensive examples:


* Governance challenges manifest in outdated versions of applications lurking in production and decommissioned applications, causing immediate concerns.
* Compliance violations, from PII leakage to HIPAA violations, reveal that the regulatory framework for LCNC apps is not as robust as it should be.
* The age-old security concerns of unauthorized data access and default passwords persist, challenging the perception that LCNC platforms offer foolproof protection.

 **Four Crucial Security Steps**[#](#four-crucial-security-steps)
----------------------------------------------------------------


In the ebook "[Low-Code/No-Code And Rpa: Rewards And Risk](https://nokodsecurity.com/low-code-no-code-and-rpa-rewards-risks/?utm_source=media&utm_medium=article&utm_campaign=THN2023)," security researchers at Nokod Security suggest that a four-step process can and should be introduced to LCNC app development. 


1. **Discovery** - Establishing and maintaining comprehensive visibility over all applications and automations is essential for robust security. An accurate, up-to-date inventory is imperative to overcome blind spots and ensure the proper security and compliance processes.
2. **Monitoring** - Comprehensive monitoring involves evaluating third-party components, implementing processes to confirm the absence of malicious code, and preventing accidental data leaks. Effectively thwarting the risk of critical data leaks requires a meticulous identification and classification of data usage, ensuring applications and automation systems handle data under their respective classifications. Governance includes proactively monitoring developer activity, particularly scrutinizing modifications made in the production environment post-publication.
3. **Act on Violations** - Efficient remediation must involve the citizen developer. Use clear communication in accessible language and with the LCNC platform-specific terminology, accompanied by step-by-step remediation guidance. You must bring in the necessary compensating controls when tackling tricky remediation scenarios.
4. **Protecting the Apps** - Use runtime controls to detect malicious behavior inside your apps and automations or by apps in your domain.


While the steps outlined above provide a foundation, the reality of a growing attack surface, uncovered by the current application security stack, forces a reevaluation. Manual security processes are not scaling enough when organizations churn out dozens of LCNC applications and RPA automations weekly. The efficacy of a manual approach is limited, especially when companies are using several LCNC and RPA platforms. It is time for dedicated security solutions for LCNC application security.


**Nokod Security: Pioneering Low-code/no-code App Security** [#](#nokod-security-pioneering-lowcodenocode-app-security)
-----------------------------------------------------------------------------------------------------------------------


Offering a central security solution, the Nokod Security platform addresses this evolving and complex threat landscape and the uniqueness of the LCNC app development.


The Nokod platform provides a centralized security, governance, and compliance solution for LCNC applications and RPA automations. By managing cybersecurity and compliance risks, Nokod streamlines security throughout the entire lifecycle of LCNC applications.


Key features of Nokod's enterprise-ready platform include:


* Discovery of all low-code/no-code applications and automations within your organization
* Placement of these applications under specified policies
* Identification of security issues and detection of vulnerabilities
* Auto-remediation and empowerment tools for low-code / no-code / RPA developers
* Enabling enhanced productivity with lean security teams


**Conclusion:**[#](#conclusion)
-------------------------------


In the dynamic landscape of contemporary business technologies, the widespread adoption of low-code/no-code (LCNC) and robotic process automation (RPA) platforms by organizations has ushered in a new era. Despite the surge in innovation, a critical security gap exists. Enterprises must gain comprehensive insights into whether these cutting-edge applications are compliant, free from vulnerabilities, or harbor malicious activities. This expanding attack surface, often unnoticed by current application security measures, poses a considerable risk.


For more timely information about low-code/no-code app security, [follow Nokod Security on LinkedIn](https://www.linkedin.com/company/nokodsecurity). 


  





## Tags:


### Autogenerated tags:
lcnc rpa low-code/no-code apps nokod automations teams
