# A CISOs Practical Guide to Storage and Backup Ransomware Resiliency
## Protecting your organization against ransomware starts with a solid storage and backup strategy. Check out this practical guide for CISOs.
## Information:

+ Link: https://thehackernews.com/2023/02/a-cisos-practical-guide-to-storage-and.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 14 February 2023, 10:12
+ Date scraped: 14 February 2023, 11:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEidL4DZhG5MTV0U0dzXcCGdnTvvlHaNE1mHjeTAKLqTdRIFK_SiDP-b--RJOd80D7sumFBya-XfI35Y12S_psCNXgUebjOQ0NIWJ8XT520hPcbQlF5eybBZaOcCRB2eX40TAfCPHRvCEzimUEDnuNOgQR3WOyhMJhCursdZHbC3toc09wEfT0jlQUbw/s728-e3650/ciso.png)


One thing is clear. The "*business value"* of data continues to grow, making it an organization's primary piece of intellectual property.


From a cyber risk perspective, attacks on data are the most prominent threat to organizations.


Regulators, cyber insurance firms, and auditors are paying much closer attention to the integrity, resilience, and recoverability of organization data – as well as the IT infrastructure & systems that store the data.


## **What Impact Does This Have On The Security Of Storage & Backup Systems?**[#](#what-impact-does-this-have-on-the-security-of-storage-backup-systems)


Just a few years ago, almost no CISO thought that storage & backups were important. That's no longer the case today.


Ransomware has pushed backup and recovery back onto the IT and corporate agenda.


Cybercriminals, such as Conti, Hive and REvil, are [targeting storage and backup](https://www.continuitysoftware.com/resources/?resources_category=headlines) systems, to prevent recovery.


Some ransomwares – Locky and Crypto, for example – now bypass production systems altogether, and directly target backups.


This has forced organizations to look again at potential holes in their safety nets, by reviewing their storage, backup, and data recovery strategies.


## **CISO Point of View**[#](#ciso-point-of-view)


To get insights on new storage, backup, and data protection methods, [8 CISOs were interviewed](https://www.continuitysoftware.com/resources/ciso-point-of-view-the-ever-changing-role-of-data-and-the-implications-for-data-protection-storage-security/). Here are some of those lessons.


![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)
CISOs are concerned about the rise of ransomware – not only of the proliferation of attacks but also of their sophistication: "*The storage and backup environments are now under attack, as the attackers realize that this is the single biggest determining factor to show if the company will pay the ransom,*" says **George Eapen**, Group CIO (and former CISO) at Petrofac, 


**John Meakin**, former CISO at GlaxoSmithKline, BP, Standard Chartered, and Deutsche Bank believes that "*As important as it may be, data encryption is hardly enough to protect an organization's core data. If attackers find their way into a storage system (as data encryption alone won't prevent them from doing so), they are free to cause severe damage by deleting and compromising petabytes of data – whether they're encrypted or not. This also includes the snapshots and backup.*"


Without a sound storage, backup, and data recovery strategy, organizations have little chance of surviving a ransomware attack, even if they end up paying the ransom.


## **Shared Responsibility - CISO vs. Storage & Backup Vendor**[#](#shared-responsibility-ciso-vs-storage-backup-vendor)


While storage & backup vendors provide excellent tools for managing availability and performance of their infrastructure, they don't do the same for the security and configuration of those same systems.


Some storage and backup vendors publish security best practice guides. However, implementation and monitoring of security features and configurations is the responsibility of an organization's security department.


There are, however, a number of cyber resiliency initiatives that are being carried out. These include:


## **Current Ransomware Resiliency Initiatives For Storage & Backup:**[#](#current-ransomware-resiliency-initiatives-for-storage-backup)


#### **Air-gapped data copies**[#](#airgapped-data-copies)


Adding an air-gap means separating backups from production data. This means that if the production environment is breached, attackers don't immediately have access to backups.


You can also keep storage accounts separate.


#### **Storage snapshots & replication**[#](#storage-snapshots-replication)


Snapshots record the live state of a system to another location, whether that's on-premises or in the cloud. So, if ransomware hits the production system, there is every chance it will be replicated onto the copy.


#### **Immutable storage & vault**[#](#immutable-storage-vault)


Immutable storage is the simplest way to protect backup data. Data is stored in a Write Once Read Many (WORM) state and cannot be deleted for a pre-specified period.


Policies are set in backup software or at storage level and it means backups can't be changed or encrypted.


While immutability is helpful in remediating cyberthreats, it is certainly not bullet proof.


Immutable storage can be 'poisoned', enabling hackers to change the configuration of backup clients and gradually replace stored data with meaningless information. In addition, once hackers gain access to the storage system, they can easily wipe out snapshots.


#### **Storage security posture management**[#](#storage-security-posture-management)


Storage security posture management solutions help you get a full view of the security risks in your storage & backup systems. It does this by continuously scanning these systems, to automatically detect security misconfigurations and vulnerabilities.


It also prioritizes risks in order of urgency and business impact, and provides remediation guidance.


[![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhhSyofmVfuy5k-uEsFczcOru4aJCun6QScQwf9d7xFgt2UL0EqQnPCz_Y3yIxuZBrzroA41QZXPsiafIkRraVuQtjtY6a6uB_R1sJe0Bpe7f0Ec9SaDIXKhNnjgyKPd1izco1DK2eaFPiB05rOZhsyrNt4iBIRzDpsq7F8h6CZ6Mq9cJkHlkUxEt5h/s728-e365/rr.png)
### **4 Steps to Success**[#](#4-steps-to-success)


1. Define comprehensive security baselines for all components of storage and backup systems ([NIST Special Publication 800-209; Security Guidelines for Storage Infrastructure](https://www.continuitysoftware.com/resources/nist-guide-for-storage-security-2/) provides a comprehensive set of recommendations for the secure deployment, configuration, and operation of storage & backup systems)
2. Use automation to reduce exposure to risk, and allow much more agility in adapting to changing priorities. Storage security posture management (also known as storage vulnerability management) solutions can go a long way to helping you reduce this exposure.
3. Apply much stricter controls and more comprehensive testing of storage and backup security, and the ability to recover from an attack. This will not only improve confidence, but will also help identify key data assets that might not meet the required level of data protection
4. Include all aspects of storage and backup management, including often-overlooked key components such as fiber-channel network devices, management consoles, etc.


[![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjDEJZBAsnVNXY6mMKMQJ6sOD8hwH07ZGa5KAx75ovRZVLx2GaQ5bAy71CzyzsKyxREKHAtqgE35n8C3n7js1hf5zbypAgON-wcLDJF9QfmVBNatyKcyWL3_GOWrMTB1_P4fnw0tz8NUusbB1psatb71GlCxTvT5-SXJ0B_TaZwULfbOJlXmrjUlVO6/s728-e365/nist.png)
[NIST Special Publication 800-209; Security Guidelines for Storage Infrastructure](https://www.continuitysoftware.com/resources/nist-guide-for-storage-security-2/) provides an overview of the evolution of storage technology, recent security threats, and the risks they pose.


It includes a comprehensive set of recommendations for the secure deployment, configuration, and operation of storage resources. These include data and confidentiality protection using encryption, isolation and restoration assurance.


  





## Tags:


### Autogenerated tags:
ciso ransomware
